@@ -11,8 +11,9 @@ class UserNode(DjangoObjectType):
     class Meta:
         model = get_user_model()
         filter_fields = app_settings.USER_NODE_FILTER_FIELDS
-        exclude_fields = app_settings.USER_NODE_EXCLUDE_FIELDS
+        exclude = app_settings.USER_NODE_EXCLUDE_FIELDS
         interfaces = (graphene.relay.Node,)
+        skip_registry = True
 
     pk = graphene.Int()
     archived = graphene.Boolean()
