@@ -1,6 +1,6 @@
 import graphene
 
-from graphql_auth.schema import UserQuery
+from graphql_auth.schema import UserQuery, MeQuery
 from graphql_auth import mutations
 
 
@@ -25,7 +25,7 @@ class AuthMutation(graphene.ObjectType):
     revoke_token = mutations.RevokeToken.Field()
 
 
-class Query(UserQuery, graphene.ObjectType):
+class Query(UserQuery, MeQuery, graphene.ObjectType):
     pass
 
 
